All the mail mirrored from lore.kernel.org
 help / color / mirror / Atom feed
* Patch "drm/radeon/native: Send out the full AUX address" has been added to the 4.1-stable tree
@ 2015-09-15 22:27 gregkh
  0 siblings, 0 replies; only message in thread
From: gregkh @ 2015-09-15 22:27 UTC (permalink / raw
  To: alexander.deucher, christian.koenig, gregkh; +Cc: stable, stable-commits


This is a note to let you know that I've just added the patch titled

    drm/radeon/native: Send out the full AUX address

to the 4.1-stable tree which can be found at:
    http://www.kernel.org/git/?p=linux/kernel/git/stable/stable-queue.git;a=summary

The filename of the patch is:
     drm-radeon-native-send-out-the-full-aux-address.patch
and it can be found in the queue-4.1 subdirectory.

If you, or anyone else, feels it should not be added to the stable tree,
please let <stable@vger.kernel.org> know about it.


>From 7040c399aea2b0213a9aefd73e507369a6d641d6 Mon Sep 17 00:00:00 2001
From: Alex Deucher <alexander.deucher@amd.com>
Date: Mon, 31 Aug 2015 11:15:05 -0400
Subject: drm/radeon/native: Send out the full AUX address
MIME-Version: 1.0
Content-Type: text/plain; charset=UTF-8
Content-Transfer-Encoding: 8bit

From: Alex Deucher <alexander.deucher@amd.com>

commit 7040c399aea2b0213a9aefd73e507369a6d641d6 upstream.

AUX addresses are 20 bits long. Send out the entire address instead of
just the low 16 bits.

Port of:
drm/radeon/atom: Send out the full AUX address
to radeon non-atom aux path

Reviewed-by: Christian König <christian.koenig@amd.com>
Signed-off-by: Alex Deucher <alexander.deucher@amd.com>
Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>

---
 drivers/gpu/drm/radeon/radeon_dp_auxch.c |    4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

--- a/drivers/gpu/drm/radeon/radeon_dp_auxch.c
+++ b/drivers/gpu/drm/radeon/radeon_dp_auxch.c
@@ -116,8 +116,8 @@ radeon_dp_aux_transfer_native(struct drm
 	       AUX_SW_WR_BYTES(bytes));
 
 	/* write the data header into the registers */
-	/* request, addres, msg size */
-	byte = (msg->request << 4);
+	/* request, address, msg size */
+	byte = (msg->request << 4) | ((msg->address >> 16) & 0xf);
 	WREG32(AUX_SW_DATA + aux_offset[instance],
 	       AUX_SW_DATA_MASK(byte) | AUX_SW_AUTOINCREMENT_DISABLE);
 


Patches currently in stable-queue which might be from alexander.deucher@amd.com are

queue-4.1/drm-radeon-atom-send-out-the-full-aux-address.patch
queue-4.1/drm-radeon-don-t-link-train-displayport-on-hpd-until-we-get-the-dpcd.patch
queue-4.1/drm-radeon-native-send-out-the-full-aux-address.patch
queue-4.1/drm-radeon-fix-hdmi-quantization_range-for-pre-dce5-asics.patch

^ permalink raw reply	[flat|nested] only message in thread

only message in thread, other threads:[~2015-09-15 22:27 UTC | newest]

Thread overview: (only message) (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2015-09-15 22:27 Patch "drm/radeon/native: Send out the full AUX address" has been added to the 4.1-stable tree gregkh

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.